==> elisa-plugins-bad_0.5.9-1.orig.tar.gz: elisa-plugins-bad-0.5.9/elisa/plugins/pigment/widgets/progressbar.py <==
# -*- coding: utf-8 -*-
# Elisa - Home multimedia server
# Copyright (C) 2006-2008 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 3.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Elisa with Fluendo's plugins.
#
# The GPL part of Elisa is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Elisa" in the root directory of this distribution package
# for details on that license.

from elisa.plugins.pigment.widgets.range import Range

import pgm
import gobject

import logging


class ProgressBar(Range):

    def __init__(self):
        self._is_pulsing = False
        self._pulse_versus = 1
        self.sensitive = False
        self.seek_drag = False

        super(ProgressBar, self).__init__()

    def pulse_step__get(self):
        if self.items_number == 0:
            return 1.0
        return 1.0 / self.items_number

    def pulse(self):
        self._is_pulsing = True
        self.current_index += self._pulse_versus

        if self.current_index in [0, self.items_number - 1]:
            self._pulse_versus = self._pulse_versus * -1

    def set_fraction(self, fraction):
        self._is_pulsing = False

        assert(0<= fraction <= 1)
        if fraction == 0:
            self.current_index = 0
        else:
            self.current_index = int(self.items_number * fraction) - 1

    def do_index_changed(self, current, previous):
        if 0 <= current < self.items_number:
            self._update_cursor_size()

    def _update_cursor_size(self):
        if self._is_pulsing:
            return

        super(ProgressBar, self)._update_cursor_size()

    def _update_cursor_position(self):
        if self._is_pulsing:
            super(ProgressBar, self)._update_cursor_position()

    def start(self):
        self._running = True

        def _pulse():
            if self._running:
                self.pulse()
                return True
            return False

        gobject.timeout_add(250, _pulse)

    def _pressed(self, widget, x, y, z, button, time, pressure):
        if not self.sensitive:
            return True

        idx = self._get_index_from_position(x, y, z)
        if idx > self.items_number:
            # stupid but possible: move the drag over the size of the widgets
            return True

        self.current_index = idx
        return True


    def _drag_begin(self, widget, x, y, z, button, time, pressure):
        if not self.sensitive:
            return True
        
        self.seek_drag = True
        return True

    def _drag_motion(self, widget, x, y, z, button, time, pressure):
        if not self.sensitive:
            return True

        idx = self._get_index_from_position(x, y, z)
        if idx > self.items_number:
            # stupid but possible: move the drag over the size of the widgets
            return True

        self.current_index = idx
        return True

    def _drag_end(self, widget, x, y, z, button, time):
        if not self.sensitive:
            return True
        self.seek_drag = False
        return True


    def stop(self):
        self._running = False

    @classmethod
    def _demo_widget(cls, *args, **kwargs):
        widget = cls()
        widget.items_number = 12
        widget.visible = True

        return widget


if __name__ == "__main__":
    logger = logging.getLogger()
    logger.setLevel(logging.DEBUG)

    progressbar = ProgressBar.demo ()
    try:
        __IPYTHON__
    except NameError:
        pgm.main()

==> elisa-plugins-bad_0.5.28.orig.tar.gz: elisa-plugins-bad-0.5.28/elisa/plugins/pigment/widgets/progressbar.py <==
# -*- coding: utf-8 -*-
# Elisa - Home multimedia server
# Copyright (C) 2006-2008 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 3.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Elisa with Fluendo's plugins.
#
# The GPL part of Elisa is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Elisa" in the root directory of this distribution package
# for details on that license.

from elisa.plugins.pigment.widgets.range import Range

import pgm
import gobject

import logging


class ProgressBar(Range):

    def __init__(self):
        self.sensitive = False
        self.seek_drag = False

        super(ProgressBar, self).__init__()

    def set_fraction(self, fraction):

        assert(0<= fraction <= 1)
        if fraction == 0:
            self.current_index = 0
        else:
            self.current_index = int(self.items_number * fraction) - 1

    def do_index_changed(self, current, previous):
        if 0 <= current <= self.items_number:
            self._update_cursor_size()


    def _pressed(self, widget, x, y, z, button, time, pressure):
        if not self.sensitive:
            return True

        idx = self._get_index_from_position(x, y, z)
        if idx > self.items_number:
            # stupid but possible: move the drag over the size of the widgets
            return True

        self.current_index = idx
        return True


    def _drag_begin(self, widget, x, y, z, button, time, pressure):
        if not self.sensitive:
            return True

        self.seek_drag = True
        return True

    def _drag_motion(self, widget, x, y, z, button, time, pressure):
        if not self.sensitive:
            return True

        idx = self._get_index_from_position(x, y, z)
        if idx > self.items_number:
            # stupid but possible: move the drag over the size of the widgets
            return True

        self.current_index = idx
        return True

    def _drag_end(self, widget, x, y, z, button, time):
        if not self.sensitive:
            return True
        self.seek_drag = False
        return True

    @classmethod
    def _demo_widget(cls, *args, **kwargs):
        widget = cls()
        widget.items_number = 12
        widget.visible = True

        return widget


if __name__ == "__main__":
    logger = logging.getLogger()
    logger.setLevel(logging.DEBUG)

    progressbar = ProgressBar.demo ()
    try:
        __IPYTHON__
    except NameError:
        pgm.main()
